ISOTEL Data-acquisition & Metering Project offers a complete solution for wired and wireless 
communication with sensor & control devices. IDM Project strives for correct presentation of 
sensor measurements, accuracy, precision and easy description of their complex transfer 
functions to fulfil requirements of accurate metering and precise control in control systems.
It simplifies integration into sensor networks and Internet of Things while offering a
rapid development of custom embedded hardware solutions.

The isotel-idm python package provides an API for IDM Smart Gateway for easy integration 
into analysis frameworks like python/jupyter, automated test systems, and integration into 
other Internet of Things platforms.

For more information visit http://isotel.eu/idm project home page.
